@@ -8,7 +8,9 @@ use warnings;
 use Carp;
 use base qw{ Exporter };
 
-our $VERSION = '0.018';
+our $VERSION = '0.020';
+
+no warnings qw{ once };	# For older Perls.
 
 our @CARP_NOT = qw{
     PPIx::QuoteLike
@@ -25,6 +27,8 @@ our @CARP_NOT = qw{
     PPIx::QuoteLike::Utils
 };
 
+use warnings qw{ once };
+
 our @EXPORT_OK = qw{
     ARRAY_REF
     MINIMUM_PERL
@@ -142,7 +146,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2021 by Thomas R. Wyant, III
+Copyright (C) 2016-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
